@@ -7,8 +7,6 @@ import (
 
 	"github.com/go-test/deep"
 	"github.com/spf13/afero"
-
-	"github.com/anchore/go-version"
 )
 
 func mustUrl(u *url.URL, err error) *url.URL {
@@ -18,13 +16,6 @@ func mustUrl(u *url.URL, err error) *url.URL {
 	return u
 }
 
-func mustConst(u version.Constraints, err error) version.Constraints {
-	if err != nil {
-		panic(err)
-	}
-	return u
-}
-
 func TestNewListingFromPath(t *testing.T) {
 	tests := []struct {
 		fixture  string
