@@ -100,9 +100,7 @@ func (d *Differ) setOrDownload(curator *db.Curator, filenameOrURL string) error
 func download(curator *db.Curator, listing *db.ListingEntry) error {
 	// let consumers know of a monitorable event (download + import stages)
 	importProgress := progress.NewManual(1)
-	stage := &progress.Stage{
-		Current: "checking available databases",
-	}
+	stage := progress.NewAtomicStage("checking available databases")
 	downloadProgress := progress.NewManual(1)
 	aggregateProgress := progress.NewAggregator(progress.DefaultStrategy, downloadProgress, importProgress)
 
