@@ -9,7 +9,7 @@ import (
 
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/pkg"
-	"github.com/anchore/grype/internal"
+	"github.com/anchore/grype/internal/stringutil"
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
@@ -33,7 +33,7 @@ func TestMatcherPortage_Match(t *testing.T) {
 
 	assert.Len(t, actual, 1, "unexpected indirect matches count")
 
-	foundCVEs := internal.NewStringSet()
+	foundCVEs := stringutil.NewStringSet()
 	for _, a := range actual {
 		foundCVEs.Add(a.Vulnerability.ID)
 
