@@ -4,10 +4,12 @@ import (
 	"bytes"
 	"flag"
 	"regexp"
+	"sort"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 
+	"github.com/anchore/clio"
 	"github.com/anchore/go-testutils"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
@@ -25,6 +27,10 @@ func TestJsonImgsPresenter(t *testing.T) {
 	matches, packages, context, metadataProvider, _, _ := internal.GenerateAnalysis(t, internal.ImageSource)
 
 	pb := models.PresenterConfig{
+		ID: clio.Identification{
+			Name:    "grype",
+			Version: "[not provided]",
+		},
 		Matches:          matches,
 		Packages:         packages,
 		Context:          context,
@@ -58,6 +64,10 @@ func TestJsonDirsPresenter(t *testing.T) {
 	matches, packages, context, metadataProvider, _, _ := internal.GenerateAnalysis(t, internal.DirectorySource)
 
 	pb := models.PresenterConfig{
+		ID: clio.Identification{
+			Name:    "grype",
+			Version: "[not provided]",
+		},
 		Matches:          matches,
 		Packages:         packages,
 		Context:          context,
@@ -101,6 +111,10 @@ func TestEmptyJsonPresenter(t *testing.T) {
 	}
 
 	pb := models.PresenterConfig{
+		ID: clio.Identification{
+			Name:    "grype",
+			Version: "[not provided]",
+		},
 		Matches:          matches,
 		Packages:         nil,
 		Context:          ctx,
@@ -126,6 +140,18 @@ func TestEmptyJsonPresenter(t *testing.T) {
 
 }
 
+func TestPresenter_Present_NewDocumentSorted(t *testing.T) {
+	matches, packages, context, metadataProvider, appConfig, dbStatus := internal.GenerateAnalysis(t, internal.ImageSource)
+	doc, err := models.NewDocument(clio.Identification{}, packages, context, matches, nil, metadataProvider, appConfig, dbStatus)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	if !sort.IsSorted(models.MatchSort(doc.Matches)) {
+		t.Errorf("expected matches to be sorted")
+	}
+}
+
 func redact(content []byte) []byte {
 	return timestampRegexp.ReplaceAll(content, []byte(`"timestamp":""`))
 }
