@@ -12,39 +12,38 @@ type source struct {
 }
 
 // newSource creates a new source object to be represented into JSON.
-func newSource(src syftSource.Metadata) (source, error) {
-	switch src.Scheme {
-	case syftSource.ImageScheme:
-		metadata := src.ImageMetadata
+func newSource(src syftSource.Description) (source, error) {
+	switch m := src.Metadata.(type) {
+	case syftSource.StereoscopeImageSourceMetadata:
 		// ensure that empty collections are not shown as null
-		if metadata.RepoDigests == nil {
-			metadata.RepoDigests = []string{}
+		if m.RepoDigests == nil {
+			m.RepoDigests = []string{}
 		}
-		if metadata.Tags == nil {
-			metadata.Tags = []string{}
+		if m.Tags == nil {
+			m.Tags = []string{}
 		}
 
 		return source{
 			Type:   "image",
-			Target: metadata,
+			Target: m,
 		}, nil
-	case syftSource.DirectoryScheme:
+	case syftSource.DirectorySourceMetadata:
 		return source{
 			Type:   "directory",
-			Target: src.Path,
+			Target: m.Path,
 		}, nil
-	case syftSource.FileScheme:
+	case syftSource.FileSourceMetadata:
 		return source{
 			Type:   "file",
-			Target: src.Path,
+			Target: m.Path,
 		}, nil
-	case "":
+	case nil:
 		// we may be showing results from a input source that does not support source information
 		return source{
 			Type:   "unknown",
 			Target: "unknown",
 		}, nil
 	default:
-		return source{}, fmt.Errorf("unsupported source: %q", src.Scheme)
+		return source{}, fmt.Errorf("unsupported source: %T", src.Metadata)
 	}
 }
