@@ -2,14 +2,14 @@ package table
 
 import (
 	"bytes"
-	"flag"
 	"testing"
 
+	"github.com/gkampitakis/go-snaps/snaps"
 	"github.com/go-test/deep"
-	"github.com/sergi/go-diff/diffmatchpatch"
+	"github.com/google/go-cmp/cmp"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
-	"github.com/anchore/go-testutils"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/presenter/internal"
@@ -18,8 +18,6 @@ import (
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
-var update = flag.Bool("update", false, "update the *.golden files for table presenters")
-
 func TestCreateRow(t *testing.T) {
 	pkg1 := pkg.Package{
 		ID:      "package-1-id",
@@ -74,7 +72,6 @@ func TestCreateRow(t *testing.T) {
 }
 
 func TestTablePresenter(t *testing.T) {
-
 	var buffer bytes.Buffer
 	matches, packages, _, metadataProvider, _, _ := internal.GenerateAnalysis(t, internal.ImageSource)
 
@@ -88,21 +85,10 @@ func TestTablePresenter(t *testing.T) {
 
 	// run presenter
 	err := pres.Present(&buffer)
-	if err != nil {
-		t.Fatal(err)
-	}
-	actual := buffer.Bytes()
-	if *update {
-		testutils.UpdateGoldenFileContents(t, actual)
-	}
+	require.NoError(t, err)
 
-	var expected = testutils.GetGoldenFileContents(t)
-
-	if !bytes.Equal(expected, actual) {
-		dmp := diffmatchpatch.New()
-		diffs := dmp.DiffMain(string(expected), string(actual), true)
-		t.Errorf("mismatched output:\n%s", dmp.DiffPrettyText(diffs))
-	}
+	actual := buffer.String()
+	snaps.MatchSnapshot(t, actual)
 
 	// TODO: add me back in when there is a JSON schema
 	// validateAgainstDbSchema(t, string(actual))
@@ -125,22 +111,10 @@ func TestEmptyTablePresenter(t *testing.T) {
 
 	// run presenter
 	err := pres.Present(&buffer)
-	if err != nil {
-		t.Fatal(err)
-	}
-	actual := buffer.Bytes()
-	if *update {
-		testutils.UpdateGoldenFileContents(t, actual)
-	}
-
-	var expected = testutils.GetGoldenFileContents(t)
-
-	if !bytes.Equal(expected, actual) {
-		dmp := diffmatchpatch.New()
-		diffs := dmp.DiffMain(string(expected), string(actual), true)
-		t.Errorf("mismatched output:\n%s", dmp.DiffPrettyText(diffs))
-	}
+	require.NoError(t, err)
 
+	actual := buffer.String()
+	snaps.MatchSnapshot(t, actual)
 }
 
 func TestRemoveDuplicateRows(t *testing.T) {
@@ -169,7 +143,36 @@ func TestRemoveDuplicateRows(t *testing.T) {
 			t.Errorf("   diff: %+v", d)
 		}
 	}
+}
 
+func TestSortRows(t *testing.T) {
+	data := [][]string{
+		{"a", "v0.1.0", "", "deb", "CVE-2019-9996", "Critical"},
+		{"a", "v0.1.0", "", "deb", "CVE-2018-9996", "Critical"},
+		{"a", "v0.2.0", "", "deb", "CVE-2010-9996", "High"},
+		{"b", "v0.2.0", "", "deb", "CVE-2010-9996", "Medium"},
+		{"b", "v0.2.0", "", "deb", "CVE-2019-9996", "High"},
+		{"d", "v0.4.0", "", "node", "CVE-2011-9996", "Low"},
+		{"d", "v0.4.0", "", "node", "CVE-2012-9996", "Negligible"},
+		{"c", "v0.6.0", "", "node", "CVE-2013-9996", "Critical"},
+	}
+
+	expected := [][]string{
+		{"a", "v0.1.0", "", "deb", "CVE-2019-9996", "Critical"},
+		{"a", "v0.1.0", "", "deb", "CVE-2018-9996", "Critical"},
+		{"a", "v0.2.0", "", "deb", "CVE-2010-9996", "High"},
+		{"b", "v0.2.0", "", "deb", "CVE-2019-9996", "High"},
+		{"b", "v0.2.0", "", "deb", "CVE-2010-9996", "Medium"},
+		{"c", "v0.6.0", "", "node", "CVE-2013-9996", "Critical"},
+		{"d", "v0.4.0", "", "node", "CVE-2011-9996", "Low"},
+		{"d", "v0.4.0", "", "node", "CVE-2012-9996", "Negligible"},
+	}
+
+	actual := sortRows(data)
+
+	if diff := cmp.Diff(expected, actual); diff != "" {
+		t.Errorf("sortRows() mismatch (-want +got):\n%s", diff)
+	}
 }
 
 func TestHidesIgnoredMatches(t *testing.T) {
@@ -186,21 +189,10 @@ func TestHidesIgnoredMatches(t *testing.T) {
 	pres := NewPresenter(pb, false)
 
 	err := pres.Present(&buffer)
-	if err != nil {
-		t.Fatal(err)
-	}
-	actual := buffer.Bytes()
-	if *update {
-		testutils.UpdateGoldenFileContents(t, actual)
-	}
+	require.NoError(t, err)
 
-	var expected = testutils.GetGoldenFileContents(t)
-
-	if !bytes.Equal(expected, actual) {
-		dmp := diffmatchpatch.New()
-		diffs := dmp.DiffMain(string(expected), string(actual), true)
-		t.Errorf("mismatched output:\n%s", dmp.DiffPrettyText(diffs))
-	}
+	actual := buffer.String()
+	snaps.MatchSnapshot(t, actual)
 }
 
 func TestDisplaysIgnoredMatches(t *testing.T) {
@@ -217,19 +209,8 @@ func TestDisplaysIgnoredMatches(t *testing.T) {
 	pres := NewPresenter(pb, true)
 
 	err := pres.Present(&buffer)
-	if err != nil {
-		t.Fatal(err)
-	}
-	actual := buffer.Bytes()
-	if *update {
-		testutils.UpdateGoldenFileContents(t, actual)
-	}
+	require.NoError(t, err)
 
-	var expected = testutils.GetGoldenFileContents(t)
-
-	if !bytes.Equal(expected, actual) {
-		dmp := diffmatchpatch.New()
-		diffs := dmp.DiffMain(string(expected), string(actual), true)
-		t.Errorf("mismatched output:\n%s", dmp.DiffPrettyText(diffs))
-	}
+	actual := buffer.String()
+	snaps.MatchSnapshot(t, actual)
 }
